import React, { memo, useMemo } from 'react';
import { Text, View, TouchableOpacity, StyleSheet } from 'react-native';
import { useCalendarContext } from '../CalendarContext';
const DaySelector = () => {
  const {
    utils,
    currentDate,
    selectedDate,
    onSelectDate,
    theme
  } = useCalendarContext();
  const month = utils.getDateMonth(currentDate);
  const year = utils.getDateYear(currentDate);
  const days = useMemo(() => utils.getMonthDays(currentDate),
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [month, year]);
  const handleSelectDate = date => {
    const newDate = utils.getDate(date).hour(utils.getDateHour(currentDate)).minute(utils.getDateMinute(currentDate));
    onSelectDate(utils.getFormated(newDate));
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.weekDaysContainer, theme === null || theme === void 0 ? void 0 : theme.weekDaysContainerStyle]
  }, utils.getWeekdaysMin().map((item, index) => /*#__PURE__*/React.createElement(View, {
    key: index,
    style: styles.weekDayCell
  }, /*#__PURE__*/React.createElement(Text, {
    style: theme === null || theme === void 0 ? void 0 : theme.weekDaysTextStyle
  }, item)))), /*#__PURE__*/React.createElement(View, {
    style: styles.daysContainer
  }, days.map((day, index) => {
    const dayContainerStyle = day && day.isCurrentMonth ? theme === null || theme === void 0 ? void 0 : theme.dayContainerStyle : {
      opacity: 0.3
    };
    const todayItemStyle = day && day.date === utils.getToday() ? {
      borderWidth: 2,
      borderColor: (theme === null || theme === void 0 ? void 0 : theme.selectedItemColor) || '#0047FF'
    } : null;
    const activeItemStyle = day && day.date === utils.getFormatedDate(selectedDate, 'YYYY/MM/DD') ? {
      borderColor: (theme === null || theme === void 0 ? void 0 : theme.selectedItemColor) || '#0047FF',
      backgroundColor: (theme === null || theme === void 0 ? void 0 : theme.selectedItemColor) || '#0047FF'
    } : null;
    const textStyle = day && day.date === utils.getFormatedDate(selectedDate, 'YYYY/MM/DD') ? {
      color: '#fff',
      ...(theme === null || theme === void 0 ? void 0 : theme.selectedTextStyle)
    } : day && day.date === utils.getToday() ? {
      ...(theme === null || theme === void 0 ? void 0 : theme.calendarTextStyle),
      color: (theme === null || theme === void 0 ? void 0 : theme.selectedItemColor) || '#0047FF'
    } : theme === null || theme === void 0 ? void 0 : theme.calendarTextStyle;
    return /*#__PURE__*/React.createElement(View, {
      key: index,
      style: styles.dayCell
    }, day && day.disabled ? /*#__PURE__*/React.createElement(View, {
      style: [styles.dayContainer, dayContainerStyle, todayItemStyle, activeItemStyle, styles.disabledDay]
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.dayTextContainer
    }, /*#__PURE__*/React.createElement(Text, {
      style: textStyle
    }, day.text))) : day ? /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: () => handleSelectDate(day.date),
      style: [styles.dayContainer, dayContainerStyle, todayItemStyle, activeItemStyle]
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.dayTextContainer
    }, /*#__PURE__*/React.createElement(Text, {
      style: textStyle
    }, day.text))) : null);
  })));
};
const styles = StyleSheet.create({
  container: {
    flex: 1,
    paddingTop: 5
  },
  weekDaysContainer: {
    width: '100%',
    flexDirection: 'row',
    paddingBottom: 10,
    paddingTop: 5,
    marginBottom: 10,
    alignItems: 'center',
    borderBottomWidth: 1,
    borderColor: '#E5E5E5'
  },
  weekDayCell: {
    width: '14.2%',
    alignItems: 'center',
    justifyContent: 'center'
  },
  daysContainer: {
    width: '100%',
    height: '100%',
    flexWrap: 'wrap',
    flexDirection: 'row'
  },
  dayCell: {
    width: '14.2%',
    height: '14.2%'
  },
  dayContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    margin: 1.5,
    borderRadius: 100
  },
  dayTextContainer: {
    justifyContent: 'center',
    alignItems: 'center'
  },
  disabledDay: {
    opacity: 0.3
  }
});
export default /*#__PURE__*/memo(DaySelector);
//# sourceMappingURL=DaySelector.js.map