import dayjs from 'dayjs';
import localeData from 'dayjs/plugin/localeData';
import relativeTime from 'dayjs/plugin/relativeTime';
dayjs.extend(localeData);
dayjs.extend(relativeTime);
export default class utils {
  constructor(_ref) {
    let {
      mode,
      locale,
      minimumDate,
      maximumDate,
      displayFullDays
    } = _ref;
    this.mode = mode;
    this.minimumDate = minimumDate;
    this.maximumDate = maximumDate;
    this.displayFullDays = displayFullDays;
    this.config = {
      calendarFormat: 'YYYY/MM/DD HH:mm',
      dateFormat: 'YYYY/MM/DD',
      timeFormat: 'HH:mm'
    };
    dayjs.locale(locale);
  }
  getMonths = () => dayjs.months();
  getMonthName = month => dayjs.months()[month];
  getWeekdays = () => dayjs.weekdays();
  getWeekdaysShort = () => dayjs.weekdaysShort();
  getWeekdaysMin = () => dayjs.weekdaysMin();
  getDateFormated = date => dayjs(date).format(this.config.dateFormat);
  getTimeFormated = date => dayjs(date).format(this.config.timeFormat);
  getFormated = date => dayjs(date).format(this.config.calendarFormat);
  getFormatedValue = date => {
    if (this.mode === 'time') {
      const now = dayjs().format('YYYY/MM/DD');
      return dayjs(now + ' ' + date).format(this.config.calendarFormat);
    } else return dayjs(date).format(this.config.calendarFormat);
  };
  getNow = () => {
    if (this.mode !== 'datetime') {
      const now = dayjs().startOf('day');
      return now.format(this.config.calendarFormat);
    } else return dayjs().format(this.config.calendarFormat);
  };
  getDateMonth = date => dayjs(date).month();
  getDateYear = date => dayjs(date).year();
  getDateHour = date => dayjs(date).hour();
  getDateMinute = date => dayjs(date).minute();
  getToday = () => dayjs().format(this.config.dateFormat);
  getFormatedDate = (date, format) => dayjs(date).format(format);
  getDate = date => dayjs(date, this.config.calendarFormat);

  /**
   * Calculate month days array based on current date
   *
   * @param {DateType} datetime The current date that selected
   * @returns {IDayObject[]} days array based on current date
   */
  getMonthDays = datetime => {
    let date = this.getDate(datetime);
    const currentMonthDays = date.daysInMonth();
    const prevMonthDays = date.add(-1, 'month').daysInMonth();
    const firstDay = date.date(1);
    const dayOfMonth = firstDay.day() % 7;
    const prevDaysArray = Array.from({
      length: dayOfMonth
    }, (_, i) => i + (prevMonthDays - dayOfMonth + 1));
    const monthDaysOffset = dayOfMonth + currentMonthDays;
    const nextMonthDays = this.displayFullDays ? monthDaysOffset > 35 ? 42 - monthDaysOffset : 35 - monthDaysOffset : 0;
    const prevDays = this.displayFullDays ? prevDaysArray.map(day => {
      const thisDay = date.add(-1, 'month').date(day);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: day.toString(),
        day,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    }) : new Array(dayOfMonth);
    return [...prevDays, ...Array.from({
      length: currentMonthDays
    }, (_, i) => {
      const thisDay = date.date(i + 1);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: true
      };
    }), ...Array.from({
      length: nextMonthDays
    }, (_, i) => {
      const thisDay = date.add(1, 'month').date(i + 1);
      let disabled = false;
      if (this.minimumDate) {
        disabled = thisDay < this.getDate(this.minimumDate);
      }
      if (this.maximumDate && !disabled) {
        disabled = thisDay > this.getDate(this.maximumDate);
      }
      return {
        text: (i + 1).toString(),
        day: i + 1,
        date: this.getFormatedDate(thisDay, 'YYYY/MM/DD'),
        disabled,
        isCurrentMonth: false
      };
    })];
  };
}
//# sourceMappingURL=utils.js.map